Test implementation of IJWTVerifier.
A real verifier is supplied by the application, which knows what issues its
tokens. See wagoe.realtime.ports/IJWTVerifier.
Test implementation of IJWTVerifier. A real verifier is supplied by the application, which knows what issues its tokens. See `wagoe.realtime.ports/IJWTVerifier`.
(create-test-jwt-adapter test-claims)Create test JWT adapter for testing without user module.
Args: test-claims - Map with claims to return for :expected-token Must include :expected-token key
Example: (create-test-jwt-adapter {:expected-token "test-token-123" :user-id #uuid "..." :email "test@example.com" :roles #{:user}})
Returns: TestJWTAdapter instance
Create test JWT adapter for testing without user module.
Args:
test-claims - Map with claims to return for :expected-token
Must include :expected-token key
Example:
(create-test-jwt-adapter
{:expected-token "test-token-123"
:user-id #uuid "..."
:email "test@example.com"
:roles #{:user}})
Returns:
TestJWTAdapter instancecljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |